==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Barycentric_coordinates_2/group__PkgBarycentricCoordinates2RefConcepts.js <==
var group__PkgBarycentricCoordinates2RefConcepts =
[
    [ "BarycentricCoordinates_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html", [
      [ "BarycentricCoordinates_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#a75ff3e74f7b0e37956b2752d89022e6a", null ],
      [ "coordinates_on_bounded_side", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#a8f014db2cf41feb73c7ed81886eaa6ea", null ],
      [ "coordinates_on_unbounded_side", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#a3fe36889df02f565077f37610d5be937", null ],
      [ "weights", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#ad4f81c91f3125760007048b0a1d15aab", null ]
    ] ],
    [ "BarycentricTraits_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html", [
      [ "Collinear_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ac41c1e6937a0aec866ab2aa4e0b66da1", null ],
      [ "Collinear_are_ordered_along_line_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a152851559a5a207d440b7ff8c84dc8f8", null ],
      [ "Compare_x_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a34a1be5e16c296d544e385cdca56f9d1", null ],
      [ "Compare_y_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a78dc8fad426342fc62167b366cd6928d", null ],
      [ "Comparison_result", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a00b77d15743ea624372e2c3d95c0bebe", null ],
      [ "Compute_area_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a0bbafd4d8834499cb3821c059d84abd7", null ],
      [ "Compute_determinant_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a9c905bd7601a01b51263fe6d5d618746", null ],
      [ "Compute_scalar_product_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ae71f74626673a50dcdecb3f5c5099e11", null ],
      [ "Compute_squared_distance_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#af3b4a7817dcdc00166b4fc6c9778e2e5", null ],
      [ "Compute_squared_length_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ab2029c25f6c38ced959425b5eb0a2974", null ],
      [ "Construct_vector_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a4feb159da33c42d05e215c7fb78845e3", null ],
      [ "Equal_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#aa2c6944acbfbc9595f9c1fbbd69f1337", null ],
      [ "FT", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ab6cb89234abf7a82eead3a813f46c19f", null ],
      [ "Less_xy_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#adeb0ec9534bd75c03c505126071d45bb", null ],
      [ "Orientation", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#aa0a512d491e859e488a649b50a9e9e70", null ],
      [ "Orientation_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a412478947fce0c8e962109b69468b017", null ],
      [ "Point_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a2004d1b3526c00f3224b2de4a1fdc3f9", null ],
      [ "Vector_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#adf807938cfbdfc7ec6bd8c47fa5e15b2", null ]
    ] ],
    [ "DiscretizedDomain_2", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html", [
      [ "is_on_boundary", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#aefcf06b888475fa2d25f8dd7bc79f774", null ],
      [ "locate", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#a93fb63783fdc4dd84852340cbc24f782", null ],
      [ "number_of_vertices", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#ad3923891ef4f73ad940bfa141195b7f8", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#aae99d239310ef83f65004df7b1b186df", null ],
      [ "vertex", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#a5ad5cbefe9cc4877e9850246dd88a9cf", null ]
    ] ]
];

==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Barycentric_coordinates_2/group__PkgBarycentricCoordinates2RefConcepts.js <==
var group__PkgBarycentricCoordinates2RefConcepts =
[
    [ "CGAL::Barycentric_coordinates::BarycentricCoordinates_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html", [
      [ "BarycentricCoordinates_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#a75ff3e74f7b0e37956b2752d89022e6a", null ],
      [ "coordinates_on_bounded_side", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#a5dc84c7c3d96a5d15694e5d13009dc99", null ],
      [ "coordinates_on_unbounded_side", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#a6bc9527767b8fdab64de1a0802fbcb97", null ],
      [ "weights", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricCoordinates__2.html#a5e5300b178174dc4aa3036f05f45b969", null ]
    ] ],
    [ "CGAL::Barycentric_coordinates::BarycentricTraits_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html", [
      [ "Collinear_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ac41c1e6937a0aec866ab2aa4e0b66da1", null ],
      [ "Collinear_are_ordered_along_line_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a152851559a5a207d440b7ff8c84dc8f8", null ],
      [ "Compare_x_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a34a1be5e16c296d544e385cdca56f9d1", null ],
      [ "Compare_y_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a78dc8fad426342fc62167b366cd6928d", null ],
      [ "Comparison_result", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a00b77d15743ea624372e2c3d95c0bebe", null ],
      [ "Compute_area_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a0bbafd4d8834499cb3821c059d84abd7", null ],
      [ "Compute_determinant_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a9c905bd7601a01b51263fe6d5d618746", null ],
      [ "Compute_scalar_product_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ae71f74626673a50dcdecb3f5c5099e11", null ],
      [ "Compute_squared_distance_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#af3b4a7817dcdc00166b4fc6c9778e2e5", null ],
      [ "Compute_squared_length_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ab2029c25f6c38ced959425b5eb0a2974", null ],
      [ "Construct_vector_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a4feb159da33c42d05e215c7fb78845e3", null ],
      [ "Equal_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#aa2c6944acbfbc9595f9c1fbbd69f1337", null ],
      [ "FT", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#ab6cb89234abf7a82eead3a813f46c19f", null ],
      [ "Less_xy_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#adeb0ec9534bd75c03c505126071d45bb", null ],
      [ "Orientation", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#aa0a512d491e859e488a649b50a9e9e70", null ],
      [ "Orientation_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a412478947fce0c8e962109b69468b017", null ],
      [ "Point_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#a2004d1b3526c00f3224b2de4a1fdc3f9", null ],
      [ "Vector_2", "classCGAL_1_1Barycentric__coordinates_1_1BarycentricTraits__2.html#adf807938cfbdfc7ec6bd8c47fa5e15b2", null ]
    ] ],
    [ "CGAL::Barycentric_coordinates::DiscretizedDomain_2", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html", [
      [ "is_on_boundary", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#aefcf06b888475fa2d25f8dd7bc79f774", null ],
      [ "locate", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#a93fb63783fdc4dd84852340cbc24f782", null ],
      [ "number_of_vertices", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#ad3923891ef4f73ad940bfa141195b7f8", null ],
      [ "operator()", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#aae99d239310ef83f65004df7b1b186df", null ],
      [ "vertex", "classCGAL_1_1Barycentric__coordinates_1_1DiscretizedDomain__2.html#a7707e68e11da330839832ab3ad3bfb86", null ]
    ] ]
];
